Module lease

Module lease 

Provides an API over “managed” lease

Structs

LeaseExpiredNotify
Notify when the lease has expired.
ManagedLease
Managed lease instance that will keep the lease alive until it is dropped.
ManagedLeaseFactory
Managed lease factory that will create a new lease and keep it alive until it is dropped.
ManagedLeaseWeak
Weak reference to the managed lease.

Enums

CreateLeaseError