ManagedLeaseWeak

Struct ManagedLeaseWeak 

pub struct ManagedLeaseWeak { /* private fields */ }
Weak reference to the managed lease.

This can be used to check if the lease is still alive. The reference is weak because dropping this reference will not revoke the lease.

Implementations