pub struct ManagedLockGuard<'a> { /* private fields */ }Expand description
Acquired only via ManagedLock::scope or ManagedLock::scope_with.
This guard represents the scope of the managed lock, and can be used to express restriction on code execution so that it is only executed within the lock lifetime.
This guard can also be used with other modules in the library such as the log module.