Module retry

Module retry 

Utility function to manage various transient errors.

Functions

is_transient
Check if an etcd error is transient.
retry_etcd
Retry an etcd operation by captures a reusable args and a closure that compute the future to try.
retry_etcd_get
Retry an etcd get if the error is transient.
retry_etcd_txn
Retry an etcd transaction if the error is transient.
retry_etcd_with_strategy
Similar to retry_etcd but with a custom retry strategy.
status_code_is_transient