Utility function to manage various transient errors.
Functions
- is_
transient - Check if an etcd error is transient.
- retry_
etcd - Retry an etcd operation by captures a reusable args and a closure that compute the future to try.
- retry_
etcd_ get - Retry an etcd get if the error is transient.
- retry_
etcd_ txn - Retry an etcd transaction if the error is transient.
- retry_
etcd_ with_ strategy - Similar to
retry_etcdbut with a custom retry strategy. - status_
code_ is_ transient